@@ -580,6 +580,18 @@ glade_editor_load_editable_in_page (GladeEditor          *editor,
 	return editable;
 }
 
+void
+glade_editor_set_signal_editor (GladeEditor *editor, GladeSignalEditor *signal_editor)
+{
+	if (editor->signal_editor) {
+		gtk_container_remove (GTK_CONTAINER (editor->page_signals),
+		                      glade_signal_editor_get_widget (editor->signal_editor));
+	}
+	editor->signal_editor = signal_editor;
+	gtk_container_add (GTK_CONTAINER (editor->page_signals),
+			    glade_signal_editor_get_widget (editor->signal_editor));
+}
+
 static void
 glade_editor_load_signal_page (GladeEditor *editor)
 {
