@@ -94,7 +94,10 @@ glade_marshal_VOID__POINTER_POINTER (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,ULONG,UINT,STRING (./glade-marshallers.list:2) */
+/* VOID:POINTER (./glade-marshallers.list:2) */
+#define glade_marshal_VOID__POINTER	g_cclosure_marshal_VOID__POINTER
+
+/* VOID:STRING,ULONG,UINT,STRING (./glade-marshallers.list:3) */
 extern void glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
                                                           GValue       *return_value,
                                                           guint         n_param_values,
@@ -141,10 +144,10 @@ glade_marshal_VOID__STRING_ULONG_UINT_STRING (GClosure     *closure,
             data2);
 }
 
-/* VOID:OBJECT (./glade-marshallers.list:3) */
+/* VOID:OBJECT (./glade-marshallers.list:4) */
 #define glade_marshal_VOID__OBJECT	g_cclosure_marshal_VOID__OBJECT
 
-/* VOID:OBJECT,BOOLEAN (./glade-marshallers.list:4) */
+/* VOID:OBJECT,BOOLEAN (./glade-marshallers.list:5) */
 extern void glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -187,7 +190,7 @@ glade_marshal_VOID__OBJECT_BOOLEAN (GClosure     *closure,
             data2);
 }
 
-/* VOID:STRING,STRING,STRING (./glade-marshallers.list:5) */
+/* VOID:STRING,STRING,STRING (./glade-marshallers.list:6) */
 extern void glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
                                                       GValue       *return_value,
                                                       guint         n_param_values,
@@ -232,7 +235,7 @@ glade_marshal_VOID__STRING_STRING_STRING (GClosure     *closure,
             data2);
 }
 
-/* OBJECT:POINTER (./glade-marshallers.list:6) */
+/* OBJECT:POINTER (./glade-marshallers.list:7) */
 extern void glade_marshal_OBJECT__POINTER (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -277,7 +280,7 @@ glade_marshal_OBJECT__POINTER (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* OBJECT:OBJECT,UINT (./glade-marshallers.list:7) */
+/* OBJECT:OBJECT,UINT (./glade-marshallers.list:8) */
 extern void glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
                                                GValue       *return_value,
                                                guint         n_param_values,
@@ -324,7 +327,7 @@ glade_marshal_OBJECT__OBJECT_UINT (GClosure     *closure,
   g_value_take_object (return_value, v_return);
 }
 
-/* BOOLEAN:STRING (./glade-marshallers.list:8) */
+/* BOOLEAN:STRING (./glade-marshallers.list:9) */
 extern void glade_marshal_BOOLEAN__STRING (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -369,7 +372,7 @@ glade_marshal_BOOLEAN__STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:BOXED (./glade-marshallers.list:9) */
+/* BOOLEAN:BOXED (./glade-marshallers.list:10) */
 extern void glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -414,7 +417,7 @@ glade_marshal_BOOLEAN__BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT (./glade-marshallers.list:10) */
+/* BOOLEAN:OBJECT (./glade-marshallers.list:11) */
 extern void glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
                                            GValue       *return_value,
                                            guint         n_param_values,
@@ -459,7 +462,7 @@ glade_marshal_BOOLEAN__OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOXED (./glade-marshallers.list:11) */
+/* BOOLEAN:OBJECT,BOXED (./glade-marshallers.list:12) */
 extern void glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
                                                  GValue       *return_value,
                                                  guint         n_param_values,
@@ -506,7 +509,7 @@ glade_marshal_BOOLEAN__OBJECT_BOXED (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:12) */
+/* BOOLEAN:OBJECT,POINTER (./glade-marshallers.list:13) */
 extern void glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -553,7 +556,7 @@ glade_marshal_BOOLEAN__OBJECT_POINTER (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:13) */
+/* BOOLEAN:OBJECT,BOOLEAN (./glade-marshallers.list:14) */
 extern void glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
                                                    GValue       *return_value,
                                                    guint         n_param_values,
@@ -600,7 +603,7 @@ glade_marshal_BOOLEAN__OBJECT_BOOLEAN (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:14) */
+/* BOOLEAN:OBJECT,UINT (./glade-marshallers.list:15) */
 extern void glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
                                                 GValue       *return_value,
                                                 guint         n_param_values,
@@ -647,7 +650,7 @@ glade_marshal_BOOLEAN__OBJECT_UINT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:15) */
+/* BOOLEAN:OBJECT,OBJECT (./glade-marshallers.list:16) */
 extern void glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -694,7 +697,7 @@ glade_marshal_BOOLEAN__OBJECT_OBJECT (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* BOOLEAN:OBJECT,STRING (./glade-marshallers.list:16) */
+/* BOOLEAN:OBJECT,STRING (./glade-marshallers.list:17) */
 extern void glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
                                                   GValue       *return_value,
                                                   guint         n_param_values,
@@ -741,7 +744,107 @@ glade_marshal_BOOLEAN__OBJECT_STRING (GClosure     *closure,
   g_value_set_boolean (return_value, v_return);
 }
 
-/* STRING:OBJECT (./glade-marshallers.list:17) */
+/* BOOLEAN:STRING,STRING,STRING,BOXED (./glade-marshallers.list:18) */
+extern void glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
+                                                               GValue       *return_value,
+                                                               guint         n_param_values,
+                                                               const GValue *param_values,
+                                                               gpointer      invocation_hint,
+                                                               gpointer      marshal_data);
+void
+glade_marshal_BOOLEAN__STRING_STRING_STRING_BOXED (GClosure     *closure,
+                                                   GValue       *return_value G_GNUC_UNUSED,
+                                                   guint         n_param_values,
+                                                   const GValue *param_values,
+                                                   gpointer      invocation_hint G_GNUC_UNUSED,
+                                                   gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_STRING_STRING_BOXED) (gpointer     data1,
+                                                                        gpointer     arg_1,
+                                                                        gpointer     arg_2,
+                                                                        gpointer     arg_3,
+                                                                        gpointer     arg_4,
+                                                                        gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING_STRING_STRING_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 5);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING_STRING_STRING_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_string (param_values + 2),
+                       g_marshal_value_peek_string (param_values + 3),
+                       g_marshal_value_peek_boxed (param_values + 4),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* BOOLEAN:STRING,BOXED,OBJECT (./glade-marshallers.list:19) */
+extern void glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
+                                                        GValue       *return_value,
+                                                        guint         n_param_values,
+                                                        const GValue *param_values,
+                                                        gpointer      invocation_hint,
+                                                        gpointer      marshal_data);
+void
+glade_marshal_BOOLEAN__STRING_BOXED_OBJECT (GClosure     *closure,
+                                            GValue       *return_value G_GNUC_UNUSED,
+                                            guint         n_param_values,
+                                            const GValue *param_values,
+                                            gpointer      invocation_hint G_GNUC_UNUSED,
+                                            gpointer      marshal_data)
+{
+  typedef gboolean (*GMarshalFunc_BOOLEAN__STRING_BOXED_OBJECT) (gpointer     data1,
+                                                                 gpointer     arg_1,
+                                                                 gpointer     arg_2,
+                                                                 gpointer     arg_3,
+                                                                 gpointer     data2);
+  register GMarshalFunc_BOOLEAN__STRING_BOXED_OBJECT callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gboolean v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 4);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_BOOLEAN__STRING_BOXED_OBJECT) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_string (param_values + 1),
+                       g_marshal_value_peek_boxed (param_values + 2),
+                       g_marshal_value_peek_object (param_values + 3),
+                       data2);
+
+  g_value_set_boolean (return_value, v_return);
+}
+
+/* STRING:OBJECT (./glade-marshallers.list:20) */
 extern void glade_marshal_STRING__OBJECT (GClosure     *closure,
                                           GValue       *return_value,
                                           guint         n_param_values,
@@ -786,6 +889,53 @@ glade_marshal_STRING__OBJECT (GClosure     *closure,
   g_value_take_string (return_value, v_return);
 }
 
+/* INT:OBJECT,BOXED (./glade-marshallers.list:21) */
+extern void glade_marshal_INT__OBJECT_BOXED (GClosure     *closure,
+                                             GValue       *return_value,
+                                             guint         n_param_values,
+                                             const GValue *param_values,
+                                             gpointer      invocation_hint,
+                                             gpointer      marshal_data);
+void
+glade_marshal_INT__OBJECT_BOXED (GClosure     *closure,
+                                 GValue       *return_value G_GNUC_UNUSED,
+                                 guint         n_param_values,
+                                 const GValue *param_values,
+                                 gpointer      invocation_hint G_GNUC_UNUSED,
+                                 gpointer      marshal_data)
+{
+  typedef gint (*GMarshalFunc_INT__OBJECT_BOXED) (gpointer     data1,
+                                                  gpointer     arg_1,
+                                                  gpointer     arg_2,
+                                                  gpointer     data2);
+  register GMarshalFunc_INT__OBJECT_BOXED callback;
+  register GCClosure *cc = (GCClosure*) closure;
+  register gpointer data1, data2;
+  gint v_return;
+
+  g_return_if_fail (return_value != NULL);
+  g_return_if_fail (n_param_values == 3);
+
+  if (G_CCLOSURE_SWAP_DATA (closure))
+    {
+      data1 = closure->data;
+      data2 = g_value_peek_pointer (param_values + 0);
+    }
+  else
+    {
+      data1 = g_value_peek_pointer (param_values + 0);
+      data2 = closure->data;
+    }
+  callback = (GMarshalFunc_INT__OBJECT_BOXED) (marshal_data ? marshal_data : cc->callback);
+
+  v_return = callback (data1,
+                       g_marshal_value_peek_object (param_values + 1),
+                       g_marshal_value_peek_boxed (param_values + 2),
+                       data2);
+
+  g_value_set_int (return_value, v_return);
+}
+
 G_END_DECLS
 
 #endif /* __glade_marshal_MARSHAL_H__ */
